@@ -21,19 +21,13 @@ from .mini_template_dto import MiniTemplateDto
 from .paginated_list_of_record_dto import PaginatedListOfRecordDto
 from .patch_mini_command import PatchMiniCommand
 from .problem_details import ProblemDetails
-from .record import Record
-from .record_attachment import RecordAttachment
 from .record_attachment_dto import RecordAttachmentDto
 from .record_attachment_dto_metadata_type_0 import RecordAttachmentDtoMetadataType0
-from .record_attachment_metadata_type_0 import RecordAttachmentMetadataType0
-from .record_authorization import RecordAuthorization
 from .record_authorization_dto import RecordAuthorizationDto
 from .record_dto import RecordDto
 from .record_dto_tags import RecordDtoTags
-from .record_relation import RecordRelation
 from .record_relation_dto import RecordRelationDto
 from .record_state import RecordState
-from .record_tag import RecordTag
 from .record_tag_dto import RecordTagDto
 from .slim_mini_dto import SlimMiniDto
 from .tool_dto import ToolDto
@@ -72,19 +66,13 @@ __all__ = (
     "PaginatedListOfRecordDto",
     "PatchMiniCommand",
     "ProblemDetails",
-    "Record",
-    "RecordAttachment",
     "RecordAttachmentDto",
     "RecordAttachmentDtoMetadataType0",
-    "RecordAttachmentMetadataType0",
-    "RecordAuthorization",
     "RecordAuthorizationDto",
     "RecordDto",
     "RecordDtoTags",
-    "RecordRelation",
     "RecordRelationDto",
     "RecordState",
-    "RecordTag",
     "RecordTagDto",
     "SlimMiniDto",
     "ToolDto",
